@@ -1,5 +1,7 @@
       integer NpMax
       parameter( NpMax = 50000 )
+      integer  fnoB
+      parameter  (fnoB=4)  ! hybrid AS output file no.
 
       structure /ob/
         integer*2 where, code, subcode, charge
